@@ -1,4 +1,5 @@
 // Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package repo
 
@@ -7,7 +8,7 @@ import (
 	"sync"
 
 	"github.com/fsnotify/fsnotify"
-	"github.com/stolostron/multiclusterhub-repo/pkg/config"
+	"github.com/open-cluster-management/multiclusterhub-repo/pkg/config"
 )
 
 // Server holds an index.yaml
